# pulp_container-client
Fetch, Upload, Organize, and Distribute Software Packages

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v3
- Package version: 2.8.2
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://pulpproject.org](https://pulpproject.org)

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import pulpcore.client.pulp_container
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import pulpcore.client.pulp_container
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function

import time
import pulpcore.client.pulp_container
from pulpcore.client.pulp_container.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://pulp
# See configuration.py for a list of all supported configuration parameters.
configuration = pulpcore.client.pulp_container.Configuration(
    host = "https://pulp"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicAuth
configuration = pulpcore.client.pulp_container.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)

# Configure API key authorization: cookieAuth
configuration = pulpcore.client.pulp_container.Configuration(
    host = "https://pulp",
    api_key = {
        'Session': 'YOUR_API_KEY'
    }
)
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Session'] = 'Bearer'


# Enter a context with an instance of the API client
with pulpcore.client.pulp_container.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = pulpcore.client.pulp_container.ContentBlobsApi(api_client)
    digest = 'digest_example' # str | Filter results where digest matches value (optional)
digest__in = ['digest__in_example'] # list[str] | Filter results where digest is in a comma-separated list of values (optional)
limit = 56 # int | Number of results to return per page. (optional)
media_type = ['media_type_example'] # list[str] |  (optional)
offset = 56 # int | The initial index from which to return the results. (optional)
ordering = 'ordering_example' # str | Which field to use when ordering the results. (optional)
repository_version = 'repository_version_example' # str | Repository Version referenced by HREF (optional)
repository_version_added = 'repository_version_added_example' # str | Repository Version referenced by HREF (optional)
repository_version_removed = 'repository_version_removed_example' # str | Repository Version referenced by HREF (optional)
fields = 'fields_example' # str | A list of fields to include in the response. (optional)
exclude_fields = 'exclude_fields_example' # str | A list of fields to exclude from the response. (optional)

    try:
        # List blobs
        api_response = api_instance.list(digest=digest, digest__in=digest__in, limit=limit, media_type=media_type, offset=offset, ordering=ordering, repository_version=repository_version, repository_version_added=repository_version_added, repository_version_removed=repository_version_removed, fields=fields, exclude_fields=exclude_fields)
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ContentBlobsApi->list: %s\n" % e)
    
```

## Documentation for API Endpoints

All URIs are relative to *https://pulp*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ContentBlobsApi* | [**list**](docs/ContentBlobsApi.md#list) | **GET** /pulp/api/v3/content/container/blobs/ | List blobs
*ContentBlobsApi* | [**read**](docs/ContentBlobsApi.md#read) | **GET** {container_blob_href} | Inspect a blob
*ContentManifestsApi* | [**list**](docs/ContentManifestsApi.md#list) | **GET** /pulp/api/v3/content/container/manifests/ | List manifests
*ContentManifestsApi* | [**read**](docs/ContentManifestsApi.md#read) | **GET** {container_manifest_href} | Inspect a manifest
*ContentTagsApi* | [**list**](docs/ContentTagsApi.md#list) | **GET** /pulp/api/v3/content/container/tags/ | List tags
*ContentTagsApi* | [**read**](docs/ContentTagsApi.md#read) | **GET** {container_tag_href} | Inspect a tag
*ContentguardsContentRedirectApi* | [**create**](docs/ContentguardsContentRedirectApi.md#create) | **POST** /pulp/api/v3/contentguards/container/content_redirect/ | Create a content redirect content guard
*ContentguardsContentRedirectApi* | [**delete**](docs/ContentguardsContentRedirectApi.md#delete) | **DELETE** {container_content_redirect_content_guard_href} | Delete a content redirect content guard
*ContentguardsContentRedirectApi* | [**list**](docs/ContentguardsContentRedirectApi.md#list) | **GET** /pulp/api/v3/contentguards/container/content_redirect/ | List content redirect content guards
*ContentguardsContentRedirectApi* | [**partial_update**](docs/ContentguardsContentRedirectApi.md#partial_update) | **PATCH** {container_content_redirect_content_guard_href} | Update a content redirect content guard
*ContentguardsContentRedirectApi* | [**read**](docs/ContentguardsContentRedirectApi.md#read) | **GET** {container_content_redirect_content_guard_href} | Inspect a content redirect content guard
*ContentguardsContentRedirectApi* | [**update**](docs/ContentguardsContentRedirectApi.md#update) | **PUT** {container_content_redirect_content_guard_href} | Update a content redirect content guard
*DistributionsContainerApi* | [**create**](docs/DistributionsContainerApi.md#create) | **POST** /pulp/api/v3/distributions/container/container/ | Create a container distribution
*DistributionsContainerApi* | [**delete**](docs/DistributionsContainerApi.md#delete) | **DELETE** {container_container_distribution_href} | Delete a container distribution
*DistributionsContainerApi* | [**list**](docs/DistributionsContainerApi.md#list) | **GET** /pulp/api/v3/distributions/container/container/ | List container distributions
*DistributionsContainerApi* | [**partial_update**](docs/DistributionsContainerApi.md#partial_update) | **PATCH** {container_container_distribution_href} | Update a container distribution
*DistributionsContainerApi* | [**read**](docs/DistributionsContainerApi.md#read) | **GET** {container_container_distribution_href} | Inspect a container distribution
*DistributionsContainerApi* | [**update**](docs/DistributionsContainerApi.md#update) | **PUT** {container_container_distribution_href} | Update a container distribution
*PulpContainerNamespacesApi* | [**create**](docs/PulpContainerNamespacesApi.md#create) | **POST** /pulp/api/v3/pulp_container/namespaces/ | Create a container namespace
*PulpContainerNamespacesApi* | [**delete**](docs/PulpContainerNamespacesApi.md#delete) | **DELETE** {container_container_namespace_href} | Delete a container namespace
*PulpContainerNamespacesApi* | [**list**](docs/PulpContainerNamespacesApi.md#list) | **GET** /pulp/api/v3/pulp_container/namespaces/ | List container namespaces
*PulpContainerNamespacesApi* | [**read**](docs/PulpContainerNamespacesApi.md#read) | **GET** {container_container_namespace_href} | Inspect a container namespace
*RemotesContainerApi* | [**create**](docs/RemotesContainerApi.md#create) | **POST** /pulp/api/v3/remotes/container/container/ | Create a container remote
*RemotesContainerApi* | [**delete**](docs/RemotesContainerApi.md#delete) | **DELETE** {container_container_remote_href} | Delete a container remote
*RemotesContainerApi* | [**list**](docs/RemotesContainerApi.md#list) | **GET** /pulp/api/v3/remotes/container/container/ | List container remotes
*RemotesContainerApi* | [**partial_update**](docs/RemotesContainerApi.md#partial_update) | **PATCH** {container_container_remote_href} | Update a container remote
*RemotesContainerApi* | [**read**](docs/RemotesContainerApi.md#read) | **GET** {container_container_remote_href} | Inspect a container remote
*RemotesContainerApi* | [**update**](docs/RemotesContainerApi.md#update) | **PUT** {container_container_remote_href} | Update a container remote
*RepositoriesContainerApi* | [**add**](docs/RepositoriesContainerApi.md#add) | **POST** {container_container_repository_href}add/ | Add content
*RepositoriesContainerApi* | [**build_image**](docs/RepositoriesContainerApi.md#build_image) | **POST** {container_container_repository_href}build_image/ | Build an Image
*RepositoriesContainerApi* | [**copy_manifests**](docs/RepositoriesContainerApi.md#copy_manifests) | **POST** {container_container_repository_href}copy_manifests/ | Copy manifests
*RepositoriesContainerApi* | [**copy_tags**](docs/RepositoriesContainerApi.md#copy_tags) | **POST** {container_container_repository_href}copy_tags/ | Copy tags
*RepositoriesContainerApi* | [**create**](docs/RepositoriesContainerApi.md#create) | **POST** /pulp/api/v3/repositories/container/container/ | Create a container repository
*RepositoriesContainerApi* | [**delete**](docs/RepositoriesContainerApi.md#delete) | **DELETE** {container_container_repository_href} | Delete a container repository
*RepositoriesContainerApi* | [**list**](docs/RepositoriesContainerApi.md#list) | **GET** /pulp/api/v3/repositories/container/container/ | List container repositorys
*RepositoriesContainerApi* | [**partial_update**](docs/RepositoriesContainerApi.md#partial_update) | **PATCH** {container_container_repository_href} | Update a container repository
*RepositoriesContainerApi* | [**read**](docs/RepositoriesContainerApi.md#read) | **GET** {container_container_repository_href} | Inspect a container repository
*RepositoriesContainerApi* | [**remove**](docs/RepositoriesContainerApi.md#remove) | **POST** {container_container_repository_href}remove/ | Remove content
*RepositoriesContainerApi* | [**sync**](docs/RepositoriesContainerApi.md#sync) | **POST** {container_container_repository_href}sync/ | Sync from a remote
*RepositoriesContainerApi* | [**tag**](docs/RepositoriesContainerApi.md#tag) | **POST** {container_container_repository_href}tag/ | Create a Tag
*RepositoriesContainerApi* | [**untag**](docs/RepositoriesContainerApi.md#untag) | **POST** {container_container_repository_href}untag/ | Delete a tag
*RepositoriesContainerApi* | [**update**](docs/RepositoriesContainerApi.md#update) | **PUT** {container_container_repository_href} | Update a container repository
*RepositoriesContainerPushApi* | [**list**](docs/RepositoriesContainerPushApi.md#list) | **GET** /pulp/api/v3/repositories/container/container-push/ | List container push repositorys
*RepositoriesContainerPushApi* | [**partial_update**](docs/RepositoriesContainerPushApi.md#partial_update) | **PATCH** {container_container_push_repository_href} | Update a container push repository
*RepositoriesContainerPushApi* | [**read**](docs/RepositoriesContainerPushApi.md#read) | **GET** {container_container_push_repository_href} | Inspect a container push repository
*RepositoriesContainerPushApi* | [**remove_image**](docs/RepositoriesContainerPushApi.md#remove_image) | **POST** {container_container_push_repository_href}remove_image/ | Delete an image from a repository
*RepositoriesContainerPushApi* | [**tag**](docs/RepositoriesContainerPushApi.md#tag) | **POST** {container_container_push_repository_href}tag/ | Create a Tag
*RepositoriesContainerPushApi* | [**untag**](docs/RepositoriesContainerPushApi.md#untag) | **POST** {container_container_push_repository_href}untag/ | Delete a tag
*RepositoriesContainerPushApi* | [**update**](docs/RepositoriesContainerPushApi.md#update) | **PUT** {container_container_push_repository_href} | Update a container push repository
*RepositoriesContainerPushVersionsApi* | [**delete**](docs/RepositoriesContainerPushVersionsApi.md#delete) | **DELETE** {container_container_push_repository_version_href} | Delete a repository version
*RepositoriesContainerPushVersionsApi* | [**list**](docs/RepositoriesContainerPushVersionsApi.md#list) | **GET** {container_container_push_repository_href}versions/ | List repository versions
*RepositoriesContainerPushVersionsApi* | [**read**](docs/RepositoriesContainerPushVersionsApi.md#read) | **GET** {container_container_push_repository_version_href} | Inspect a repository version
*RepositoriesContainerPushVersionsApi* | [**repair**](docs/RepositoriesContainerPushVersionsApi.md#repair) | **POST** {container_container_push_repository_version_href}repair/ | 
*RepositoriesContainerVersionsApi* | [**delete**](docs/RepositoriesContainerVersionsApi.md#delete) | **DELETE** {container_container_repository_version_href} | Delete a repository version
*RepositoriesContainerVersionsApi* | [**list**](docs/RepositoriesContainerVersionsApi.md#list) | **GET** {container_container_repository_href}versions/ | List repository versions
*RepositoriesContainerVersionsApi* | [**read**](docs/RepositoriesContainerVersionsApi.md#read) | **GET** {container_container_repository_version_href} | Inspect a repository version
*RepositoriesContainerVersionsApi* | [**repair**](docs/RepositoriesContainerVersionsApi.md#repair) | **POST** {container_container_repository_version_href}repair/ | 
*TokenApi* | [**get**](docs/TokenApi.md#get) | **GET** /token/ | 


## Documentation For Models

 - [AsyncOperationResponse](docs/AsyncOperationResponse.md)
 - [ContainerBlobResponse](docs/ContainerBlobResponse.md)
 - [ContainerContainerDistribution](docs/ContainerContainerDistribution.md)
 - [ContainerContainerDistributionResponse](docs/ContainerContainerDistributionResponse.md)
 - [ContainerContainerNamespace](docs/ContainerContainerNamespace.md)
 - [ContainerContainerNamespaceResponse](docs/ContainerContainerNamespaceResponse.md)
 - [ContainerContainerPushRepository](docs/ContainerContainerPushRepository.md)
 - [ContainerContainerPushRepositoryResponse](docs/ContainerContainerPushRepositoryResponse.md)
 - [ContainerContainerRemote](docs/ContainerContainerRemote.md)
 - [ContainerContainerRemoteResponse](docs/ContainerContainerRemoteResponse.md)
 - [ContainerContainerRepository](docs/ContainerContainerRepository.md)
 - [ContainerContainerRepositoryResponse](docs/ContainerContainerRepositoryResponse.md)
 - [ContainerContentRedirectContentGuard](docs/ContainerContentRedirectContentGuard.md)
 - [ContainerContentRedirectContentGuardResponse](docs/ContainerContentRedirectContentGuardResponse.md)
 - [ContainerManifestResponse](docs/ContainerManifestResponse.md)
 - [ContainerTagResponse](docs/ContainerTagResponse.md)
 - [ContentSummary](docs/ContentSummary.md)
 - [ContentSummaryResponse](docs/ContentSummaryResponse.md)
 - [ManifestCopy](docs/ManifestCopy.md)
 - [MediaTypesEnum](docs/MediaTypesEnum.md)
 - [OCIBuildImage](docs/OCIBuildImage.md)
 - [PaginatedRepositoryVersionResponseList](docs/PaginatedRepositoryVersionResponseList.md)
 - [PaginatedcontainerBlobResponseList](docs/PaginatedcontainerBlobResponseList.md)
 - [PaginatedcontainerContainerDistributionResponseList](docs/PaginatedcontainerContainerDistributionResponseList.md)
 - [PaginatedcontainerContainerNamespaceResponseList](docs/PaginatedcontainerContainerNamespaceResponseList.md)
 - [PaginatedcontainerContainerPushRepositoryResponseList](docs/PaginatedcontainerContainerPushRepositoryResponseList.md)
 - [PaginatedcontainerContainerRemoteResponseList](docs/PaginatedcontainerContainerRemoteResponseList.md)
 - [PaginatedcontainerContainerRepositoryResponseList](docs/PaginatedcontainerContainerRepositoryResponseList.md)
 - [PaginatedcontainerContentRedirectContentGuardResponseList](docs/PaginatedcontainerContentRedirectContentGuardResponseList.md)
 - [PaginatedcontainerManifestResponseList](docs/PaginatedcontainerManifestResponseList.md)
 - [PaginatedcontainerTagResponseList](docs/PaginatedcontainerTagResponseList.md)
 - [PatchedcontainerContainerDistribution](docs/PatchedcontainerContainerDistribution.md)
 - [PatchedcontainerContainerPushRepository](docs/PatchedcontainerContainerPushRepository.md)
 - [PatchedcontainerContainerRemote](docs/PatchedcontainerContainerRemote.md)
 - [PatchedcontainerContainerRepository](docs/PatchedcontainerContainerRepository.md)
 - [PatchedcontainerContentRedirectContentGuard](docs/PatchedcontainerContentRedirectContentGuard.md)
 - [PolicyEnum](docs/PolicyEnum.md)
 - [RecursiveManage](docs/RecursiveManage.md)
 - [RemoveImage](docs/RemoveImage.md)
 - [RepositorySyncURL](docs/RepositorySyncURL.md)
 - [RepositoryVersion](docs/RepositoryVersion.md)
 - [RepositoryVersionResponse](docs/RepositoryVersionResponse.md)
 - [TagCopy](docs/TagCopy.md)
 - [TagImage](docs/TagImage.md)
 - [UnTagImage](docs/UnTagImage.md)


## Documentation For Authorization


## basicAuth

- **Type**: HTTP basic authentication


## cookieAuth

- **Type**: API key
- **API key parameter name**: Session
- **Location**: 


## Author

pulp-list@redhat.com


